@@ -451,6 +451,10 @@ void ORPrintRender::renderPage(ORODocument * pDocument, int pageNb, QPainter *pa
           renderCodeUPCE(painter, xDpi, rc, bc->data(), bc);
         else if(bc->format().contains("datamatrix"))
           renderCodeDatamatrix(painter, rc, bc->data(), bc);
+        else if(bc->format().contains("PDF417"))
+          renderPDF417(painter, xDpi, rc, bc->data(), bc);
+        else if(bc->format().contains("QR"))
+          renderQR(painter, xDpi, rc, bc->data(), bc);
         else
         {
           painter->drawText(rc, 0, "ERR: [" + bc->format() + "]" + bc->data());
@@ -477,6 +481,8 @@ void ORPrintRender::renderPage(ORODocument * pDocument, int pageNb, QPainter *pa
       QImage img = im->image();
       if(im->scaled())
         img = img.scaled(rc.size().toSize(), (Qt::AspectRatioMode)im->aspectRatioMode(), (Qt::TransformationMode)im->transformationMode());
+      else
+        img = img.scaled(QSize(img.width()*(int)xDpi/150, img.height()*(int)yDpi/150), Qt::KeepAspectRatio);
 
       QRectF sr = QRectF(QPointF(0.0, 0.0), rc.size().boundedTo(img.size()));
       painter->drawImage(rc.topLeft(), img, sr);
