@@ -1,6 +1,6 @@
 /*
  * OpenRPT report writer and rendering engine
- * Copyright (C) 2001-2012 by OpenMFG, LLC
+ * Copyright (C) 2001-2014 by OpenMFG, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,7 +21,7 @@
 #ifndef CROSSTABEDITOR_H
 #define CROSSTABEDITOR_H
 
-#include <QtGui/QDialog>
+#include <QDialog>
 
 #include "ui_crosstabeditor.h"
 
