@@ -468,7 +468,7 @@ The root node is not &apos;report&apos;.</source>
     <message>
         <location filename="parameterproperties.ui" line="20"/>
         <source>Type:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Тип:</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="34"/>
@@ -477,7 +477,7 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.cpp" line="274"/>
         <location filename="parameterproperties.cpp" line="301"/>
         <source>String</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Строка</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="39"/>
@@ -486,7 +486,7 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.cpp" line="280"/>
         <location filename="parameterproperties.cpp" line="307"/>
         <source>Bool</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Bool</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="44"/>
@@ -504,7 +504,7 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.cpp" line="278"/>
         <location filename="parameterproperties.cpp" line="305"/>
         <source>Double</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Двойной</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="54"/>
@@ -513,12 +513,12 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.cpp" line="282"/>
         <location filename="parameterproperties.cpp" line="309"/>
         <source>List</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Список</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="72"/>
         <source>Name:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Название:</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="95"/>
@@ -526,79 +526,79 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.ui" line="155"/>
         <location filename="parameterproperties.ui" line="175"/>
         <source>Value:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Значение:</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="135"/>
         <source>False</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">False</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="140"/>
         <source>True</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">True</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="192"/>
         <source>Values:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Значения:</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="210"/>
         <source>&amp;New</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Создать</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="213"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+N</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="230"/>
         <source>Move &amp;Up</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">В&amp;верх</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="233"/>
         <source>Alt+U</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+U</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="240"/>
         <source>&amp;Edit</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">&amp;Изменить</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="243"/>
         <source>Alt+E</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+E</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="250"/>
         <source>Move &amp;Down</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">В&amp;низ</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="253"/>
         <source>Alt+D</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Alt+D</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="270"/>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Удалить</translation>
     </message>
     <message>
         <location filename="parameterproperties.ui" line="299"/>
         <source>Active</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Активный</translation>
     </message>
     <message>
         <location filename="parameterproperties.cpp" line="115"/>
         <location filename="parameterproperties.cpp" line="188"/>
         <location filename="parameterproperties.cpp" line="213"/>
         <source>Warning</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Предупреждение</translation>
     </message>
     <message>
         <location filename="parameterproperties.cpp" line="116"/>
@@ -615,7 +615,7 @@ The root node is not &apos;report&apos;.</source>
         <location filename="parameterproperties.cpp" line="285"/>
         <location filename="parameterproperties.cpp" line="312"/>
         <source>Unknown Type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Неизвесный Тип</translation>
     </message>
     <message>
         <location filename="parameterproperties.cpp" line="286"/>
@@ -633,13 +633,14 @@ The root node is not &apos;report&apos;.</source>
     </message>
     <message>
         <location filename="data.cpp" line="26"/>
-        <source>Copyright (c) 2002-2011, OpenMFG, LLC.</source>
+        <source>Copyright (c) 2002-2012, OpenMFG, LLC.</source>
+        <oldsource>Copyright (c) 2002-2011, OpenMFG, LLC.</oldsource>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="data.cpp" line="28"/>
-        <source>3.3.1</source>
-        <oldsource>3.3.1Beta</oldsource>
+        <source>3.3.4</source>
+        <oldsource>3.3.1</oldsource>
         <translation type="unfinished"></translation>
     </message>
 </context>
