@@ -135,6 +135,12 @@ class ORValueAxisData
     QFont font;
     bool font_defined;
 };
+class ORPaddingData
+{
+  public:
+    int horizontal;
+    int vertical;
+};
 
 class ORCrossTabQueryData
 {
@@ -340,6 +346,8 @@ class ORGraphData : public ORObject
     ORDataAxisData dataaxis;
     ORValueAxisData valueaxis;
 
+    ORPaddingData padding;
+
     QList<ORSeriesData*> series;
 
     virtual bool isGraph();
@@ -576,6 +584,7 @@ bool parseReportTitleData(const QDomElement &, ORTitleData &);
 bool parseReportStyleData(const QDomElement &, ORStyleData &);
 bool parseReportDataAxisData(const QDomElement &, ORDataAxisData &);
 bool parseReportValueAxisData(const QDomElement &, ORValueAxisData &);
+bool parseReportPaddingData(const QDomElement &, ORPaddingData &);
 bool parseReportSeriesData(const QDomElement &, ORSeriesData &);
 
 bool parseReportSection(const QDomElement &, ORSectionData &);
